==> currents-api-types-0.0.34.tgz: package/stripe/types.ts <==
import { UserId } from '../user/types';

export enum StripeSubscriptionIdBrand {
  _ = '',
}
export type StripeSubscriptionId = string & StripeSubscriptionIdBrand;
export enum StripePaymentIntentIdBrand {
  _ = '',
}
export type StripePaymentIntentId = string & StripePaymentIntentIdBrand;
export enum StripePayoutIdBrand {
  _ = '',
}
export type StripeTipId = StripePaymentIntentId;
export type StripePayoutId = string & StripePayoutIdBrand;
export type StripeEntityId =
  | StripeCustomerId
  | StripePaymentIntentId
  | StripeProductId
  | StripePriceId
  | StripeSubscriptionId
  | StripePaymentMethodId
  | StripePayoutId
  | StripeConnectClientId;
export enum StripeInvoiceIdBrand {
  _ = '',
}
export type StripeInvoiceId = string & StripeInvoiceIdBrand;
export enum StripeCustomerIdBrand {
  _ = '',
}
export type StripeCustomerId = string & StripeCustomerIdBrand;

export enum StripePlanIdBrand {
  _ = '',
}

export type StripePlanId = string & StripePlanIdBrand;
export type StripePriceId = StripePlanId;
export enum StripeProductIdBrand {
  _ = '',
}
export type StripeProductId = string & StripeProductIdBrand;

export enum StripePaymentMethodIdBrand {
  _ = '',
}
export type StripePaymentMethodId = string & StripePaymentMethodIdBrand;

export enum StripeConnectClientIdBrand {
  _ = '',
}

// acct_
export type StripeConnectClientId = string & StripeConnectClientIdBrand;
export type StripeAccountId = StripeConnectClientId;

export enum StripeConnectClientPaymentIdBrand {
  _ = '',
}

// py_
export type StripeConnectClientPaymentId = string & StripeConnectClientPaymentIdBrand;

export enum StripeConnectTransferIdBrand {
  _ = '',
}

// tr_
// is an entity that embodies a composite key of StripeConnectClientId+StripeConnectClientPaymentId
export type StripeConnectTransferId = string & StripeConnectTransferIdBrand;

export enum StripeChargeIdBrand {
  _ = '',
}

// ch_
export type StripeChargeId = string & StripeChargeIdBrand;

// in stripe transfer object, it's destination + destination_payment
export type StripeConnectTransferCompositeKey = {
  account: StripeConnectClientId;
  payment: StripeConnectClientPaymentId;
};

export type StripeConnectTransferDestination = StripeConnectTransferCompositeKey;

export enum StripeConnectTransferReversalIdBrand {
  _ = '',
}

// trr_
// trr_ belongs to tr_; by default we have 10 reversals preloaded with transfer
export type StripeConnectTransferReversalId = string & StripeConnectTransferReversalIdBrand;

export enum StripeRefundIdBrand {
  _ = '',
}
// re_3L5GxIEv2j5aYmuj0GnizwlI
export type StripeRefundId = string & StripeRefundIdBrand;

// very common to have it
export type CustomerToUserMapping = {
  [key in StripeCustomerId]: UserId;
};

==> currents-api-types-0.0.40.tgz: package/stripe/types.ts <==
import { UserId } from '../user/types';

export enum StripeSubscriptionIdBrand {
  _ = '',
}
export type StripeSubscriptionId = string & StripeSubscriptionIdBrand;
export enum StripePaymentIntentIdBrand {
  _ = '',
}
export type StripePaymentIntentId = string & StripePaymentIntentIdBrand;
export type StripeTipId = StripePaymentIntentId;

export type StripeTransferId = StripeConnectTransferId;
/**
 * @deprecated use transfer, ref 7ad50e79-8fad-492d-b9a9-f44a0257d7a3
 */
export type StripePayoutId = StripeTransferId;
export type StripeEntityId =
  | StripeCustomerId
  | StripePaymentIntentId
  | StripeProductId
  | StripePriceId
  | StripeSubscriptionId
  | StripePaymentMethodId
  | StripeTransferId
  | StripeConnectClientId;
export enum StripeInvoiceIdBrand {
  _ = '',
}
export type StripeInvoiceId = string & StripeInvoiceIdBrand;
export enum StripeCustomerIdBrand {
  _ = '',
}
export type StripeCustomerId = string & StripeCustomerIdBrand;

export enum StripePlanIdBrand {
  _ = '',
}

export type StripePlanId = string & StripePlanIdBrand;
export type StripePriceId = StripePlanId;
export enum StripeProductIdBrand {
  _ = '',
}
export type StripeProductId = string & StripeProductIdBrand;

export enum StripePaymentMethodIdBrand {
  _ = '',
}
export type StripePaymentMethodId = string & StripePaymentMethodIdBrand;

export enum StripeConnectClientIdBrand {
  _ = '',
}

// acct_
export type StripeConnectClientId = string & StripeConnectClientIdBrand;
export type StripeAccountId = StripeConnectClientId;

export enum StripeConnectClientPaymentIdBrand {
  _ = '',
}

// py_
export type StripeConnectClientPaymentId = string & StripeConnectClientPaymentIdBrand;

export enum StripeConnectTransferIdBrand {
  _ = '',
}

// tr_
// is an entity that embodies a composite key of StripeConnectClientId+StripeConnectClientPaymentId
export type StripeConnectTransferId = string & StripeConnectTransferIdBrand;

export enum StripeChargeIdBrand {
  _ = '',
}

// ch_
export type StripeChargeId = string & StripeChargeIdBrand;

// in stripe transfer object, it's destination + destination_payment
export type StripeConnectTransferCompositeKey = {
  account: StripeConnectClientId;
  payment: StripeConnectClientPaymentId;
};

export type StripeConnectTransferDestination = StripeConnectTransferCompositeKey;

export enum StripeConnectTransferReversalIdBrand {
  _ = '',
}

// trr_
// trr_ belongs to tr_; by default we have 10 reversals preloaded with transfer
export type StripeConnectTransferReversalId = string & StripeConnectTransferReversalIdBrand;

export enum StripeRefundIdBrand {
  _ = '',
}
// re_3L5GxIEv2j5aYmuj0GnizwlI
export type StripeRefundId = string & StripeRefundIdBrand;

// very common to have it
export type CustomerToUserMapping = {
  [key in StripeCustomerId]: UserId;
};
